Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/sugar/chat
diff options
context:
space:
mode:
authorDan Williams <dcbw@localhost.localdomain>2006-07-25 22:17:05 (GMT)
committer Dan Williams <dcbw@localhost.localdomain>2006-07-25 22:17:05 (GMT)
commite5065263a9e9a8e2295d46effab39ce35d7a1349 (patch)
tree89aa1f493b4019cb79362ca6b7b0d2dd70e882b2 /sugar/chat
parent8d232ae292cf3b3b85cd34920c5eaf915c882c8a (diff)
s/publish/share
Diffstat (limited to 'sugar/chat')
-rw-r--r--sugar/chat/ActivityChat.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/sugar/chat/ActivityChat.py b/sugar/chat/ActivityChat.py
index 90b1f4b..aab83c1 100644
--- a/sugar/chat/ActivityChat.py
+++ b/sugar/chat/ActivityChat.py
@@ -38,8 +38,8 @@ class ActivityChat(GroupChat):
address=addr, port=port)
self._setup_stream(self._chat_service)
- def publish(self):
- """Only called when we publish the activity this chat is tied to."""
+ def share(self):
+ """Only called when we share the activity this chat is tied to."""
self._chat_service = self._pservice.share_activity(self._activity,
stype=ActivityChat.SERVICE_TYPE)
self._setup_stream(self._chat_service)